CREATE TABLE Person (
name VARCHAR2(60) PRIMARY KEY,
gebdat DATE NOT NULL,
kurzbio VARCHAR2(300) NOT NULL 
);

CREATE TABLE AutorIn (
name VARCHAR2(60) PRIMARY KEY REFERENCES Person (name) ON DELETE CASCADE
);

CREATE TABLE UebersetzerIn (
name VARCHAR2(60) PRIMARY KEY REFERENCES Person (name) ON DELETE CASCADE
);

CREATE TABLE LektorIn (
name VARCHAR2(60) PRIMARY KEY REFERENCES Person (name) ON DELETE CASCADE
);

CREATE TABLE Sprache (
name VARCHAR2(40) PRIMARY KEY
);

CREATE TABLE Vertrag (
vid INTEGER PRIMARY KEY,
datum DATE NOT NULL,
beschreibung VARCHAR2(200) NOT NULL,
mit VARCHAR2(60) REFERENCES Person (name) ON DELETE CASCADE
);

CREATE TABLE Werk (
titel VARCHAR2(100),
jahr DATE,
beschreibung VARCHAR2(300) NOT NULL,
CONSTRAINT pk_werk PRIMARY KEY (titel, jahr)
);

CREATE TABLE Genre (
gid INTEGER PRIMARY KEY,
name VARCHAR2(40) NOT NULL,
beschreibung VARCHAR2(200) NOT NULL
);

CREATE TABLE Auflage (
titel VARCHAR2(100),
jahr DATE,
nummer INTEGER,
aufljahr DATE NOT NULL,
CONSTRAINT pk_auflage PRIMARY KEY (titel, jahr, nummer),
CONSTRAINT fk_auflage_werk FOREIGN KEY (titel, jahr) REFERENCES Werk (titel, jahr) ON DELETE CASCADE
); 

CREATE TABLE Publikation (
titel VARCHAR2(100),
jahr DATE,
nummer INTEGER,
pid INTEGER,
seiten INTEGER NOT NULL,
CONSTRAINT pk_publikation PRIMARY KEY (titel, jahr, nummer, pid),
CONSTRAINT fk_publikation_auflage FOREIGN KEY (titel, jahr, nummer) REFERENCES Auflage (titel, jahr, nummer) ON DELETE CASCADE
);

CREATE TABLE uebersetzt_aus (
sprache VARCHAR2(40) REFERENCES Sprache (name) ON DELETE CASCADE,
name VARCHAR2(60) REFERENCES UebersetzerIn (name) ON DELETE CASCADE,
CONSTRAINT pk_uebersetzt_aus PRIMARY KEY (sprache, name)
);

CREATE TABLE uebersetzt_in (
sprache VARCHAR2(40) REFERENCES Sprache (name) ON DELETE CASCADE,
name VARCHAR2(60) REFERENCES UebersetzerIn (name) ON DELETE CASCADE,
CONSTRAINT pk_uebersetzt_in PRIMARY KEY (sprache, name)
);

CREATE TABLE arbeitet_in (
sprache VARCHAR2(40) REFERENCES Sprache (name) ON DELETE CASCADE,
name VARCHAR2(60) REFERENCES LektorIn (name) ON DELETE CASCADE,
CONSTRAINT pk_arbeitet_in PRIMARY KEY (sprache, name)
);

CREATE TABLE lektoriert (
name VARCHAR2(60) REFERENCES LektorIn (name) ON DELETE CASCADE,
titel VARCHAR2(100),
jahr DATE,
nummer INTEGER,
CONSTRAINT pk_lektoriert PRIMARY KEY (name, titel, jahr, nummer),
CONSTRAINT fk_lektoriert_auflage FOREIGN KEY (titel, jahr, nummer) REFERENCES Auflage (titel, jahr, nummer) ON DELETE CASCADE
);

CREATE TABLE Uebersetzung (
original_titel VARCHAR2(100) NOT NULL,
original_jahr DATE NOT NULL,
uebersetzung_titel VARCHAR2(100),
uebersetzung_jahr DATE,
uebersetzerin VARCHAR2(60) NOT NULL REFERENCES UebersetzerIn (name) ON DELETE CASCADE,
CONSTRAINT pk_uebersetzung PRIMARY KEY (uebersetzung_titel, uebersetzung_jahr),
CONSTRAINT fk_uebersetzung_werk FOREIGN KEY (uebersetzung_titel, uebersetzung_jahr) REFERENCES Werk (titel, jahr) ON DELETE CASCADE,
CONSTRAINT fk_uebersetzung_original FOREIGN KEY (original_titel, original_jahr) REFERENCES Werk (titel, jahr) ON DELETE CASCADE
);

CREATE TABLE schreibt (
person VARCHAR2(60) REFERENCES AutorIn (name),
titel VARCHAR2(100),
jahr DATE,
CONSTRAINT pk_schreibt PRIMARY KEY (person, titel, jahr),
CONSTRAINT fk_schreibt_werk FOREIGN KEY (titel, jahr) REFERENCES Werk (titel, jahr) ON DELETE CASCADE
);

CREATE TABLE gehoert_zu (
titel VARCHAR2(100),
jahr DATE,
gid INTEGER REFERENCES Genre (gid) ON DELETE CASCADE,
CONSTRAINT pk_gehoert_zu PRIMARY KEY (titel, jahr, gid),
CONSTRAINT fk_gehoert_zu_werk FOREIGN KEY (titel, jahr) REFERENCES Werk (titel, jahr) ON DELETE CASCADE
);

CREATE TABLE Subgenre (
untergeordnet INTEGER REFERENCES Genre (gid) ON DELETE CASCADE,
uebergeordnet INTEGER REFERENCES Genre (gid) ON DELETE CASCADE,
CONSTRAINT pk_subgenre PRIMARY KEY (untergeordnet, uebergeordnet)
);
